NATO
-------------------

One letter variables thoughtlessly strewed about a codebase annoyed a colleague and an idle thought became this poorly named project.

Uses the AST (and some cool projects like `Astor` and `codegen.py`) to quickly mangle / transform your code.

Why not just rename the variable and be done with it?
=========================================================
Excellent question!  It's fun to play at the A.S.T.!

Example usage
===================

..::

  $ python -m nato somefile.py > one_letter_variable_free.py
